docx\_parser\_converter.docx\_parsers.styles.styles\_parser module
==================================================================

.. automodule:: docx_parser_converter.docx_parsers.styles.styles_parser
   :members:
   :undoc-members:
   :show-inheritance:
